/* G4LTL: Games for LTL Synthesis
 *
 * Copyright (c) 2013, Chih-Hong Cheng fortiss (An-Institut der TU Muenchen)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The internal structure of the arena, the Muller-to-safety game reduction,
 * and the safety game engine are based on reusing/modifying components in GAVS+.
 * 
 */
package g4ltl;

import java.awt.image.BufferedImage;
import java.io.IOException;
import javax.imageio.ImageIO;


/**
 * The help window of G4LTL. Contain basic instructions.
 * 
 * @author Chihhong Cheng
 * @version 0.2 2012/08/08
 */
public class Help extends javax.swing.JFrame {

    /** Creates new GUI */
    public Help() {
        initComponents();
        BufferedImage image = null;
        try {
            image = ImageIO.read(
                    this.getClass().getResource("G4LTL.png"));
        } catch (IOException e) {
            e.printStackTrace();
        }
        this.setIconImage(image);
        this.setLocationRelativeTo(null);
    }

    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        jPanelInput = new javax.swing.JPanel();
        jTextFieldInput1 = new javax.swing.JTextField();
        jTextFieldInput2 = new javax.swing.JTextField();
        jTextFieldInput3 = new javax.swing.JTextField();
        jPanelLTLSpec = new javax.swing.JPanel();
        jTextFieldL1 = new javax.swing.JTextField();
        jTextFieldL2 = new javax.swing.JTextField();
        jTextFieldL3 = new javax.swing.JTextField();
        jTextFieldL4 = new javax.swing.JTextField();
        jTextFieldL5 = new javax.swing.JTextField();
        jTextFieldL6 = new javax.swing.JTextField();
        jTextFieldL7 = new javax.swing.JTextField();
        jTextFieldL8 = new javax.swing.JTextField();
        jTextFieldL9 = new javax.swing.JTextField();
        jTextFieldL10 = new javax.swing.JTextField();
        jPanelAlgorithm = new javax.swing.JPanel();
        jScrollPaneA1 = new javax.swing.JScrollPane();
        jTextArea1 = new javax.swing.JTextArea();

        setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
        setTitle("G4LTL: Games for LTL synthesis ");
        setIconImages(null);
        setName(""); // NOI18N
        setResizable(false);

        jPanelInput.setBorder(javax.swing.BorderFactory.createTitledBorder("Input signals and output signals"));

        jTextFieldInput1.setEditable(false);
        jTextFieldInput1.setFont(jTextFieldInput1.getFont().deriveFont(jTextFieldInput1.getFont().getSize()-2f));
        jTextFieldInput1.setText("Description: List input (output) signals, and separate them by \",\".  ");
        jTextFieldInput1.setBorder(null);

        jTextFieldInput2.setEditable(false);
        jTextFieldInput2.setFont(new java.awt.Font("Tahoma", 3, 10)); // NOI18N
        jTextFieldInput2.setForeground(new java.awt.Color(0, 0, 204));
        jTextFieldInput2.setText("req1, req2 ");

        jTextFieldInput3.setEditable(false);
        jTextFieldInput3.setFont(jTextFieldInput3.getFont().deriveFont(jTextFieldInput3.getFont().getSize()-2f));
        jTextFieldInput3.setText("Example:");
        jTextFieldInput3.setBorder(null);

        org.jdesktop.layout.GroupLayout jPanelInputLayout = new org.jdesktop.layout.GroupLayout(jPanelInput);
        jPanelInput.setLayout(jPanelInputLayout);
        jPanelInputLayout.setHorizontalGroup(
            jPanelInputLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(jPanelInputLayout.createSequentialGroup()
                .addContainerGap()
                .add(jPanelInputLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                    .add(jPanelInputLayout.createSequentialGroup()
                        .add(jTextFieldInput3, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 54, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                        .add(5, 5, 5)
                        .add(jTextFieldInput2, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 79, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                        .add(0, 0, Short.MAX_VALUE))
                    .add(org.jdesktop.layout.GroupLayout.TRAILING, jTextFieldInput1))
                .addContainerGap())
        );
        jPanelInputLayout.setVerticalGroup(
            jPanelInputLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(jPanelInputLayout.createSequentialGroup()
                .add(jTextFieldInput1, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(jPanelInputLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(jTextFieldInput3, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                    .add(jTextFieldInput2, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                .addContainerGap(org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        jPanelLTLSpec.setBorder(javax.swing.BorderFactory.createTitledBorder("LTL specification"));

        jTextFieldL1.setEditable(false);
        jTextFieldL1.setFont(jTextFieldL1.getFont().deriveFont(jTextFieldL1.getFont().getSize()-2f));
        jTextFieldL1.setText("Description 1: Use \"[]\", \"<>\", \"X\", and \"U\" for linear temporal operators");
        jTextFieldL1.setBorder(null);

        jTextFieldL2.setEditable(false);
        jTextFieldL2.setFont(jTextFieldL2.getFont().deriveFont(jTextFieldL2.getFont().getSize()-2f));
        jTextFieldL2.setText("Description 2: Use \"!\", \"&&\", \"||\", \"->\" for boolean connectives \"not\", \"and\", \"or\", \"imply\" ");
        jTextFieldL2.setBorder(null);

        jTextFieldL3.setEditable(false);
        jTextFieldL3.setFont(jTextFieldL3.getFont().deriveFont(jTextFieldL3.getFont().getSize()-2f));
        jTextFieldL3.setText("Description 3: All lines starting with \"##\" will be considered as comments and will be discarded in synthesis");
        jTextFieldL3.setBorder(null);

        jTextFieldL4.setEditable(false);
        jTextFieldL4.setFont(jTextFieldL4.getFont().deriveFont(jTextFieldL4.getFont().getSize()-2f));
        jTextFieldL4.setText("Example:");
        jTextFieldL4.setBorder(null);

        jTextFieldL5.setEditable(false);
        jTextFieldL5.setFont(new java.awt.Font("Tahoma", 3, 10)); // NOI18N
        jTextFieldL5.setForeground(new java.awt.Color(0, 0, 204));
        jTextFieldL5.setText("[] (req -> <> grant)");

        jTextFieldL6.setEditable(false);
        jTextFieldL6.setFont(new java.awt.Font("Tahoma", 0, 10)); // NOI18N
        jTextFieldL6.setText("/* Globally ([]) when signal \"req\" is true, eventually (<>) the signal \"grant\" will be true */");
        jTextFieldL6.setBorder(null);

        jTextFieldL7.setEditable(false);
        jTextFieldL7.setFont(jTextFieldL7.getFont().deriveFont(jTextFieldL7.getFont().getSize()-2f));
        jTextFieldL7.setText("Example:");
        jTextFieldL7.setBorder(null);

        jTextFieldL8.setEditable(false);
        jTextFieldL8.setFont(new java.awt.Font("Tahoma", 3, 10)); // NOI18N
        jTextFieldL8.setForeground(new java.awt.Color(0, 0, 204));
        jTextFieldL8.setText("<> (req && X grant)");

        jTextFieldL9.setEditable(false);
        jTextFieldL9.setFont(new java.awt.Font("Tahoma", 0, 10)); // NOI18N
        jTextFieldL9.setText("/* Eventually (<>) signal \"req\" is true, and the next (X) moment signal \"grant\" is true */");
        jTextFieldL9.setBorder(null);

        jTextFieldL10.setEditable(false);
        jTextFieldL10.setFont(jTextFieldL10.getFont().deriveFont(jTextFieldL10.getFont().getSize()-2f));
        jTextFieldL10.setText("Description 4: All lines starting with \"ASSUME\" will be considered as environment assumptions");
        jTextFieldL10.setBorder(null);

        org.jdesktop.layout.GroupLayout jPanelLTLSpecLayout = new org.jdesktop.layout.GroupLayout(jPanelLTLSpec);
        jPanelLTLSpec.setLayout(jPanelLTLSpecLayout);
        jPanelLTLSpecLayout.setHorizontalGroup(
            jPanelLTLSpecLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(jPanelLTLSpecLayout.createSequentialGroup()
                .addContainerGap()
                .add(jPanelLTLSpecLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                    .add(jTextFieldL2)
                    .add(jTextFieldL3, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 0, Short.MAX_VALUE)
                    .add(jPanelLTLSpecLayout.createSequentialGroup()
                        .add(jPanelLTLSpecLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                            .add(jTextFieldL7, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 54, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                            .add(org.jdesktop.layout.GroupLayout.TRAILING, jTextFieldL4, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 54, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                        .add(jPanelLTLSpecLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                            .add(jPanelLTLSpecLayout.createSequentialGroup()
                                .add(jTextFieldL8, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 109, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                                .add(jTextFieldL9))
                            .add(jPanelLTLSpecLayout.createSequentialGroup()
                                .add(jTextFieldL5, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 109, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                                .add(jTextFieldL6))))
                    .add(jPanelLTLSpecLayout.createSequentialGroup()
                        .add(jPanelLTLSpecLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                            .add(jTextFieldL1, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 453, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                            .add(jTextFieldL10, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                        .add(0, 0, Short.MAX_VALUE)))
                .addContainerGap())
        );
        jPanelLTLSpecLayout.setVerticalGroup(
            jPanelLTLSpecLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(jPanelLTLSpecLayout.createSequentialGroup()
                .add(6, 6, 6)
                .add(jTextFieldL1, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(jTextFieldL2, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(jTextFieldL3, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 15, Short.MAX_VALUE)
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(jTextFieldL10, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 14, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .add(13, 13, 13)
                .add(jPanelLTLSpecLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(jTextFieldL7, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                    .add(jTextFieldL8, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                    .add(jTextFieldL9, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(jPanelLTLSpecLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(jTextFieldL4, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                    .add(jTextFieldL5, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                    .add(jTextFieldL6, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                .addContainerGap())
        );

        jPanelAlgorithm.setBorder(javax.swing.BorderFactory.createTitledBorder("Translation from LTL to Buechi automaton"));

        jTextArea1.setColumns(20);
        jTextArea1.setEditable(false);
        jTextArea1.setFont(new java.awt.Font("Arial", 0, 12)); // NOI18N
        jTextArea1.setRows(5);
        jTextArea1.setText(" The LTL2Buchi translator (by NASA) is purely Java-based and can be executed on all platforms.\n\n LTL2BA (by ENS Cachan) is implemented in C and is not platform independent, but it is faster. \n For this we have offered several pre-compiled libraries for Windows 64 bit, Windows 32 bit and \n Linux 32 bit. To run on Windows 64 bit systems, it might be required to install .NET runtime (or \n Windows SDK) from Microsoft website. In Linux 64 bit systems, to ensure that 32 bit JVM is \n invoked, type \"java -d32 -jar G4LTL.jar\" to enforce proper JVM.\n\n For unsupported platforms, please either select LTL2Buchi or adapt the code manually.");
        jScrollPaneA1.setViewportView(jTextArea1);

        org.jdesktop.layout.GroupLayout jPanelAlgorithmLayout = new org.jdesktop.layout.GroupLayout(jPanelAlgorithm);
        jPanelAlgorithm.setLayout(jPanelAlgorithmLayout);
        jPanelAlgorithmLayout.setHorizontalGroup(
            jPanelAlgorithmLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(jPanelAlgorithmLayout.createSequentialGroup()
                .addContainerGap()
                .add(jScrollPaneA1)
                .addContainerGap())
        );
        jPanelAlgorithmLayout.setVerticalGroup(
            jPanelAlgorithmLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(jPanelAlgorithmLayout.createSequentialGroup()
                .add(jScrollPaneA1, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 142, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .add(0, 8, Short.MAX_VALUE))
        );

        org.jdesktop.layout.GroupLayout layout = new org.jdesktop.layout.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(layout.createSequentialGroup()
                .addContainerGap()
                .add(layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                    .add(org.jdesktop.layout.GroupLayout.TRAILING, layout.createSequentialGroup()
                        .add(0, 0, Short.MAX_VALUE)
                        .add(jPanelLTLSpec, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                    .add(jPanelAlgorithm, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .add(jPanelInput, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                .addContainerGap())
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(layout.createSequentialGroup()
                .addContainerGap()
                .add(jPanelInput, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 81, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(jPanelLTLSpec, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(jPanelAlgorithm, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .addContainerGap(21, Short.MAX_VALUE))
        );

        pack();
    }// </editor-fold>//GEN-END:initComponents

    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JPanel jPanelAlgorithm;
    private javax.swing.JPanel jPanelInput;
    private javax.swing.JPanel jPanelLTLSpec;
    private javax.swing.JScrollPane jScrollPaneA1;
    private javax.swing.JTextArea jTextArea1;
    private javax.swing.JTextField jTextFieldInput1;
    private javax.swing.JTextField jTextFieldInput2;
    private javax.swing.JTextField jTextFieldInput3;
    private javax.swing.JTextField jTextFieldL1;
    private javax.swing.JTextField jTextFieldL10;
    private javax.swing.JTextField jTextFieldL2;
    private javax.swing.JTextField jTextFieldL3;
    private javax.swing.JTextField jTextFieldL4;
    private javax.swing.JTextField jTextFieldL5;
    private javax.swing.JTextField jTextFieldL6;
    private javax.swing.JTextField jTextFieldL7;
    private javax.swing.JTextField jTextFieldL8;
    private javax.swing.JTextField jTextFieldL9;
    // End of variables declaration//GEN-END:variables
}
