/* G4LTL: Games for LTL Synthesis
 *
 * Copyright (c) 2013, Chih-Hong Cheng, fortiss (An-Institut der TU Muenchen)
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *   * Neither the name of the <organization> nor the
 *     names of its contributors may be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL Chih-Hong Cheng BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package g4ltl.utility;

import java.util.ArrayList;

/**
 * Store the problem (or subproblem) in a unified structure to be passed to 
 * the synthesis engine.
 * 
 * @author Chihhong Cheng
 * @version 0.2 2012/08/08
 */
public class ProblemDescription {

    private ArrayList<String> inputSignals;
    private ArrayList<String> outputSignals;
    private String ltlSpecification;
    private int unrollSteps;
    private boolean partialSpecification;

    public ProblemDescription() {
        inputSignals = new ArrayList<String>();
        outputSignals = new ArrayList<String>();
    }

    public ProblemDescription(ArrayList<String> inputSignals, ArrayList<String> outputSignals,
            String ltlSpecification, int unrollSteps, boolean partialSpecification) {

        this.inputSignals = inputSignals;
        this.outputSignals = outputSignals;
        this.ltlSpecification = ltlSpecification;
        this.unrollSteps = unrollSteps;
        this.partialSpecification = partialSpecification;

    }

    public void setInputSignals(ArrayList<String> input) {
        this.inputSignals = input;
    }

    public ArrayList<String> getInputSignals() {
        return this.inputSignals;
    }

    public void setOutputSignals(ArrayList<String> output) {
        this.outputSignals = output;
    }

    public ArrayList<String> getOutputSignals() {
        return this.outputSignals;
    }

    public void setLtlSpecification(String spec) {
        this.ltlSpecification = spec;
    }

    public String getLtlSpecification() {
        return this.ltlSpecification;
    }

    public void setUnrollSteps(int step) {
        this.unrollSteps = step;
    }

    public int getUnrollSteps() {
        return this.unrollSteps;
    }

    public void setPartialSpecification(boolean isPartial) {
        this.partialSpecification = isPartial;
    }

    public boolean isPartialSpecification() {
        return this.partialSpecification;
    }
}
